Struct dtparse::ParserInfo [−][src]
pub struct ParserInfo {
pub jump: HashMap<String, usize>,
pub weekday: HashMap<String, usize>,
pub months: HashMap<String, usize>,
pub hms: HashMap<String, usize>,
pub ampm: HashMap<String, usize>,
pub utczone: HashMap<String, usize>,
pub pertain: HashMap<String, usize>,
pub tzoffset: HashMap<String, usize>,
pub dayfirst: bool,
pub yearfirst: bool,
pub year: i32,
pub century: i32,
}Container for specific tokens to be recognized during parsing.
jump: Values that indicate the end of a token for parsing and can be ignoredweekday: Names of the days of the weekmonths: Names of the monthshms: Names for the units of time - hours, minutes, seconds in Englishampm: AM and PM tokensutczone: Tokens indicating a UTC-timezone stringpertain: Tokens indicating a "belongs to" relationship; in English this is just "of"tzoffset:dayfirst: Upon encountering an ambiguous date, treat the first value as the dayyearfirst: Upon encountering an ambiguous date, treat the first value as the yearyear: The current yearcentury: The first year in the current century
Please note that if both dayfirst and yearfirst are true, years take precedence
and will be parsed as "YDM"
Fields
jump: HashMap<String, usize>
Tokens that can be safely ignored
weekday: HashMap<String, usize>
Names of all seven weekdays
months: HashMap<String, usize>
Names of all twelve months
hms: HashMap<String, usize>
Tokens to indicate a value is in units of hours, minutes, or seconds
ampm: HashMap<String, usize>
Tokens to indicate a value refers to AM or PM time
utczone: HashMap<String, usize>
Tokens to indicate our timestamp is in the UTC timezone
pertain: HashMap<String, usize>
Tokens to indicate values "belonging" to other tokens (e.g. 3rd of March)
tzoffset: HashMap<String, usize>
Map of timezone names to their offset in seconds
dayfirst: bool
For ambiguous year/month/day values, and dayfirst was not specified as
an argument to Parser, treat the first observed value as the day.
yearfirst: bool
For ambiguous year/month/day values, and dayfirst was not specified as
an argument to Parser, treat the first observed value as the day.
Takes priority over dayfirst
year: i32
The current year we are parsing values for
century: i32
The current year we are parsing values for modulo 100